@@ -1,6 +1,7 @@
 package CIF::Client::Plugin::Csv;
 
 use Regexp::Common qw/net/;
+use Encode;
 
 sub type { return 'output'; }
 
@@ -9,15 +10,25 @@ sub write_out {
     my $config = shift;
     my $feed = shift;
     my @array = @{$feed->{'feed'}->{'entry'}};
-    my @header = keys(%{$array[0]});
+    #my @header = keys(%{$array[0]});
+    my @header;
+    # skip things like arrays and hashrefs for now
+    foreach (keys %{$array[0]}){
+        next unless(!ref($array[0]{$_}));
+        push(@header,$_);
+    }
     @header = sort { $a cmp $b } @header;
     my $body = '';
     foreach my $a (@array){
         delete($a->{'message'}); 
-        $body .= join(',',map { $a->{$_} ? $a->{$_} : ''} @header)."\n";
+        # the !ref() bits skip things like arrays and hashref's for now...
+        $body .= join(',',map { ($a->{$_} && !ref($a->{$_})) ? $a->{$_} : ''} @header)."\n";
     }
     my $text = '# '.join(',',@header);
     $text .= "\n".$body;
+    use Data::Dumper;
+    warn Dumper($text);
+
     return $text;
 }
 1;
